[Zope-Checkins] SVN: Products.Five/trunk/zcml.py Replaced error when missing site.zcml with a warning.

2006-05-31 Thread Rocky Burt
Log message for revision 68410:
  Replaced error when missing site.zcml with a warning.

Changed:
  U   Products.Five/trunk/zcml.py

-=-
Modified: Products.Five/trunk/zcml.py
===
--
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214
___
For more information about ZODB, see the ZODB Wiki:
http://www.zope.org/Wikis/ZODB/

ZODB-Dev mailing list  -  ZODB-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zodb-dev



___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Tino Wildenhain

Sidnei da Silva schrieb:

I was looking, and trying to understand why 'tempstorage' is not
included in the ZODB.

Since some people might want to share sessions between ZEO clients,
and that 'tempstorage' is what is mounted as
'/temp_folder/session_data', why not make that easy to mount via ZEO?
Does anyone see a problem with this?


actually it is easy mountable via ZEO. I'm doing this already...
Do you mean including the schema for zeo.conf per default?

Regards
Tino
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Sidnei da Silva
On Wed, May 31, 2006 at 09:53:14AM +0200, Tino Wildenhain wrote:
| Sidnei da Silva schrieb:
| I was looking, and trying to understand why 'tempstorage' is not
| included in the ZODB.
| 
| Since some people might want to share sessions between ZEO clients,
| and that 'tempstorage' is what is mounted as
| '/temp_folder/session_data', why not make that easy to mount via ZEO?
| Does anyone see a problem with this?
| 
| actually it is easy mountable via ZEO. I'm doing this already...
| Do you mean including the schema for zeo.conf per default?

Yeah, that too. I was actually thinking about the standalone ZODB
package. Or does that not exist anymore?

I was also wondering if this is the right thing to do (mounting
tempstorage via ZEO) since I don't recall seeing any tutorial that
recommended it.

-- 
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Chris McDonough


On May 31, 2006, at 9:08 AM, Sidnei da Silva wrote:


On Wed, May 31, 2006 at 09:53:14AM +0200, Tino Wildenhain wrote:
| Sidnei da Silva schrieb:
| I was looking, and trying to understand why 'tempstorage' is not
| included in the ZODB.
| 
| Since some people might want to share sessions between ZEO clients,
| and that 'tempstorage' is what is mounted as
| '/temp_folder/session_data', why not make that easy to mount via  
ZEO?

| Does anyone see a problem with this?
|
| actually it is easy mountable via ZEO. I'm doing this already...
| Do you mean including the schema for zeo.conf per default?

Yeah, that too. I was actually thinking about the standalone ZODB
package. Or does that not exist anymore?

I was also wondering if this is the right thing to do (mounting
tempstorage via ZEO) since I don't recall seeing any tutorial that
recommended it.


Should be OK, although if you're doing it because you want a fast  
storage (or one that produces fewer conflicts), ZEO takes away much  
hope of that intrinsically.


- C

___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Sidnei da Silva
On Wed, May 31, 2006 at 09:40:01AM -0400, Chris McDonough wrote:
| Should be OK, although if you're doing it because you want a fast  
| storage (or one that produces fewer conflicts), ZEO takes away much  
| hope of that intrinsically.

My goal was actually sharing sessions between zeo clients, without
resorting to zsqlsessions or similar.

-- 
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Jens Vagelpohl

-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1


On 31 May 2006, at 14:55, Sidnei da Silva wrote:


On Wed, May 31, 2006 at 09:49:49AM -0400, Chris McDonough wrote:
| I've done this (at least with FileStorage) and it's
| sllo.  Might be OK for low-traffic sites, but better
| to implement a custom session data container that stores stuff in
| SQL.  I have the beginnings of one of these if you want to see it.

Slow for using sessions? Why didn't you use tempstorage then? Or you
are just asserting that FileStorage over ZEO is noticeably slower than
directly?


Tempstorage over ZEO becomes a conflict problem when things get busy.  
We removed it in favor of local temp storages.


jens

-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.1 (Darwin)

iD8DBQFEfa1uRAx5nvEhZLIRAje/AKCINcg6oR6P8rGQVSKP/Xw98hUMAwCeK9g3
aUcDnH/w9mvtCEBquKyOElU=
=ONm3
-END PGP SIGNATURE-
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Chris McDonough
I've done this (at least with FileStorage) and it's  
sllo.  Might be OK for low-traffic sites, but better  
to implement a custom session data container that stores stuff in  
SQL.  I have the beginnings of one of these if you want to see it.


- C

On May 31, 2006, at 9:44 AM, Sidnei da Silva wrote:


On Wed, May 31, 2006 at 09:40:01AM -0400, Chris McDonough wrote:
| Should be OK, although if you're doing it because you want a fast
| storage (or one that produces fewer conflicts), ZEO takes away  
much

| hope of that intrinsically.

My goal was actually sharing sessions between zeo clients, without
resorting to zsqlsessions or similar.

--
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214



___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Sidnei da Silva
On Wed, May 31, 2006 at 09:49:49AM -0400, Chris McDonough wrote:
| I've done this (at least with FileStorage) and it's  
| sllo.  Might be OK for low-traffic sites, but better  
| to implement a custom session data container that stores stuff in  
| SQL.  I have the beginnings of one of these if you want to see it.

Slow for using sessions? Why didn't you use tempstorage then? Or you
are just asserting that FileStorage over ZEO is noticeably slower than
directly?

-- 
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


Re: [ZODB-Dev] Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Eric Brun

Hi,

I have bad experence with tempstorage on ZEO (FileStorage with no undo).
With site with 18000 users (300 per minutes) , the site hang because of 
conflict on ZEO.

I am very interested by a faster tempstorage like SQLDB

Cheers

Eric Brun
Pentila

www.pentila.com

Chris McDonough a écrit :
I've done this (at least with FileStorage) and it's 
sllo.  Might be OK for low-traffic sites, but better 
to implement a custom session data container that stores stuff in 
SQL.  I have the beginnings of one of these if you want to see it.


- C

On May 31, 2006, at 9:44 AM, Sidnei da Silva wrote:


On Wed, May 31, 2006 at 09:40:01AM -0400, Chris McDonough wrote:
| Should be OK, although if you're doing it because you want a fast
| storage (or one that produces fewer conflicts), ZEO takes away much
| hope of that intrinsically.

My goal was actually sharing sessions between zeo clients, without
resorting to zsqlsessions or similar.

--Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214



___
For more information about ZODB, see the ZODB Wiki:
http://www.zope.org/Wikis/ZODB/

ZODB-Dev mailing list  -  ZODB-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zodb-dev


___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Chris McDonough


On May 31, 2006, at 9:55 AM, Sidnei da Silva wrote:


On Wed, May 31, 2006 at 09:49:49AM -0400, Chris McDonough wrote:
| I've done this (at least with FileStorage) and it's
| sllo.  Might be OK for low-traffic sites, but better
| to implement a custom session data container that stores stuff in
| SQL.  I have the beginnings of one of these if you want to see it.

Slow for using sessions? Why didn't you use tempstorage then?


I think I thought it wouldn't have mattered.  The difference between  
using sessions against a local filestorage and one on a ZEO server  
was something like 20X.



Or you
are just asserting that FileStorage over ZEO is noticeably slower than
directly?


Yes, at least for writes.  As I assume tempstorage would be too.  And  
since sessions are all about writes, it's very noticeable.


- C

___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


[Zope-dev] Re: SVN: Zope/branches/ajung-zpt-end-game/...

2006-05-31 Thread Florent Guillaume

Tres Seaver wrote:

I agree with you that there should be BBB code that provides the old
behavior and I agree with Philipp that not using that old behavior is a
benefit for the CMF.


Sure.  I just don't want to *make* people upgrade CMF when upgrading
Zope, unless there is a reason which is important *to the CMF*.

An interesting factoid I found while spelunking this issue: the CMF (by
way of DCWorkflow) is literally the oldest consumer of the expression
machinery outside of ZPT itself!  Shane's earliest checkin of the
'Expression' module was nearly 5 years ago, and used an empty string as
the class-level default for the 'text' attribute.


FWIW the following patches gives the proper BBB behaviour.
Shall I check it in? Does it need to send a deprecation warning?

Florent

Index: Products/PageTemplates/Expressions.py
===
--- Products/PageTemplates/Expressions.py   (revision 68406)
+++ Products/PageTemplates/Expressions.py   (working copy)
@@ -99,6 +99,8 @@
 class ZopePathExpr(PathExpr):

 def __init__(self, name, expr, engine):
+if name == 'standard' and not expr:
+expr = 'nothing'
 super(ZopePathExpr, self).__init__(name, expr, engine,
boboAwareZopeTraverse)

Florent

--- Products.Five/trunk/zcml.py 2006-05-31 13:38:24 UTC (rev 68409)
+++ Products.Five/trunk/zcml.py 2006-05-31 15:12:29 UTC (rev 68410)
@@ -15,6 +15,7 @@
 
 $Id$
 
+import warnings
 import os
 from zope.configuration import xmlconfig
 
@@ -33,6 +34,7 @@
 # load instance site configuration file
 site_zcml = os.path.join(INSTANCE_HOME, etc, site.zcml)
 skel_site_zcml = os.path.join(INSTANCE_HOME, skel, etc, site.zcml)
+skel_site2_zcml = os.path.join(ZOPE_HOME, skel, etc, site.zcml)
 
 if os.path.exists(site_zcml):
 file = site_zcml
@@ -40,11 +42,12 @@
 # check for zope installation home skel during running unit tests
 file = skel_site_zcml
 else:
-msg = site.zcml is now required to live at '%s', for  \
-  sites upgraded from Zope 2.9 please copy site.zcml  \
-  from your installed Zope's skel/etc directory \
-  % site_zcml 
-raise IOError(msg)
+file = skel_site2_zcml
+msg = site.zcml should now live at '%s', for  \
+  sites upgraded from Zope 2.9 please copy '%s'  \
+  to '%s' \
+  % (site_zcml, skel_site2_zcml, site_zcml)
+warnings.warn(msg, DeprecationWarning)
 
 global _context
 _context = xmlconfig.file(file)

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/lib/python/Products/ Updated reference to a Five version that turned the site.zcml error into a warning.

2006-05-31 Thread Rocky Burt
Log message for revision 68411:
  Updated reference to a Five version that turned the site.zcml error into a 
warning.

Changed:
  _U  Zope/trunk/lib/python/Products/

-=-

Property changes on: Zope/trunk/lib/python/Products
___
Name: svn:externals
   - Five svn://svn.zope.org/repos/main/Products.Five/tags/1.5c

   + Five-r 68410 svn://svn.zope.org/repos/main/Products.Five/trunk


___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/2.10/lib/python/Products/PageTemplates/PageTemplateFile.py There must be no warning when __name__ is supplied.

2006-05-31 Thread Florent Guillaume
Log message for revision 68414:
  There must be no warning when __name__ is supplied.

Changed:
  U   Zope/branches/2.10/lib/python/Products/PageTemplates/PageTemplateFile.py

-=-
Modified: 
Zope/branches/2.10/lib/python/Products/PageTemplates/PageTemplateFile.py
===
--- Zope/branches/2.10/lib/python/Products/PageTemplates/PageTemplateFile.py
2006-05-31 17:36:17 UTC (rev 68413)
+++ Zope/branches/2.10/lib/python/Products/PageTemplates/PageTemplateFile.py
2006-05-31 17:59:21 UTC (rev 68414)
@@ -59,15 +59,13 @@
 _default_bindings = {'name_subpath': 'traverse_subpath'}
 
 def __init__(self, filename, _prefix=None, **kw):
-name = None
-if kw.has_key('__name__'):
-name = kw['__name__']
-del kw['__name__'] 
+name = kw.pop('__name__', None)
 
 basepath, ext = os.path.splitext(filename)
 
 if name:
 self.id = self.__name__ = name
+self._need__name__ = 0
 else:
 self.id = self.__name__ = os.path.basename(basepath)
 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/lib/python/Products/PageTemplates/PageTemplateFile.py Merged r68414 from 2.10 branch:

2006-05-31 Thread Florent Guillaume
Log message for revision 68415:
  Merged r68414 from 2.10 branch:
  There must be no warning when __name__ is supplied.
  

Changed:
  U   Zope/trunk/lib/python/Products/PageTemplates/PageTemplateFile.py

-=-
Modified: Zope/trunk/lib/python/Products/PageTemplates/PageTemplateFile.py
===
--- Zope/trunk/lib/python/Products/PageTemplates/PageTemplateFile.py
2006-05-31 17:59:21 UTC (rev 68414)
+++ Zope/trunk/lib/python/Products/PageTemplates/PageTemplateFile.py
2006-05-31 18:00:30 UTC (rev 68415)
@@ -59,15 +59,13 @@
 _default_bindings = {'name_subpath': 'traverse_subpath'}
 
 def __init__(self, filename, _prefix=None, **kw):
-name = None
-if kw.has_key('__name__'):
-name = kw['__name__']
-del kw['__name__'] 
+name = kw.pop('__name__', None)
 
 basepath, ext = os.path.splitext(filename)
 
 if name:
 self.id = self.__name__ = name
+self._need__name__ = 0
 else:
 self.id = self.__name__ = os.path.basename(basepath)
 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/2.10/lib/python/Products/ Updated Zope to use Five revision so copying site.zcml is no longer mandatory.

2006-05-31 Thread Rocky Burt
Log message for revision 68416:
  Updated Zope to use Five revision so copying site.zcml is no longer mandatory.

Changed:
  _U  Zope/branches/2.10/lib/python/Products/

-=-

Property changes on: Zope/branches/2.10/lib/python/Products
___
Name: svn:externals
   - Five svn://svn.zope.org/repos/main/Products.Five/tags/1.5c

   + Five-r 68410 svn://svn.zope.org/repos/main/Products.Five/trunk


___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-dev] Re: [ZODB-Dev] tempstorage to ZEO?

2006-05-31 Thread Chris McDonough

Fine by me.

- C

On May 31, 2006, at 1:22 AM, Sidnei da Silva wrote:


I was looking, and trying to understand why 'tempstorage' is not
included in the ZODB.

Since some people might want to share sessions between ZEO clients,
and that 'tempstorage' is what is mounted as
'/temp_folder/session_data', why not make that easy to mount via ZEO?
Does anyone see a problem with this?

What I'm proposing is to move 'tempstorage' to 'ZODB', since it has no
dependency on anything other than 'zLOG'.

--
Florent Guillaume, Nuxeo (Paris, France)   Director of RD
+33 1 40 33 71 59   http://nuxeo.com   [EMAIL PROTECTED]
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


[Zope-dev] Re: SVN: Zope/branches/ajung-zpt-end-game/...

2006-05-31 Thread Tres Seaver
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1

Florent Guillaume wrote:
 Tres Seaver wrote:
 
 I agree with you that there should be BBB code that provides the old
 behavior and I agree with Philipp that not using that old behavior is a
 benefit for the CMF.


 Sure.  I just don't want to *make* people upgrade CMF when upgrading
 Zope, unless there is a reason which is important *to the CMF*.

 An interesting factoid I found while spelunking this issue: the CMF (by
 way of DCWorkflow) is literally the oldest consumer of the expression
 machinery outside of ZPT itself!  Shane's earliest checkin of the
 'Expression' module was nearly 5 years ago, and used an empty string as
 the class-level default for the 'text' attribute.
 
 
 FWIW the following patches gives the proper BBB behaviour.
 Shall I check it in? Does it need to send a deprecation warning?
 
 Florent
 
 Index: Products/PageTemplates/Expressions.py
 ===
 --- Products/PageTemplates/Expressions.py(revision 68406)
 +++ Products/PageTemplates/Expressions.py(working copy)
 @@ -99,6 +99,8 @@
  class ZopePathExpr(PathExpr):
 
  def __init__(self, name, expr, engine):
 +if name == 'standard' and not expr:
 +expr = 'nothing'
  super(ZopePathExpr, self).__init__(name, expr, engine,
 boboAwareZopeTraverse)
 

I uploaded a similar one, except with deprecation warning, to the
collector issue I added:

 http://www.zope.org/Collectors/Zope/2118

My variation also creates an expression which would raise a KeyError if
evaluated, rather than returning None.  I don't think anybody can
actually be depending on what the current code gives back if an empty
expression is called, so yours should be equally fine.

WRT dprecation:  I would actually prefer no* to have the warning,
myself;  I don't think that a usage which has been workable for so long
is actually in error.

We should probably add a test which verifies compilability of empty
expressions, plus whichever behavior we specify.


Tres.
- --
===
Tres Seaver  +1 202-558-7113  [EMAIL PROTECTED]
Palladion Software   Excellence by Designhttp://palladion.com
-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.1 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://enigmail.mozdev.org

iD8DBQFEfdBg+gerLs4ltQ4RAv3dAJ9nupwaHlRIwjs/0x7jPjswZ8+28ACcDzJj
BhQgjD0j0eobvHNhejOo2Mk=
=N7uW
-END PGP SIGNATURE-
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


[Zope-dev] Re: SVN: Zope/branches/ajung-zpt-end-game/...

2006-05-31 Thread Florent Guillaume

On 31 May 2006, at 19:20, Tres Seaver wrote:

I uploaded a similar one, except with deprecation warning, to the
collector issue I added:

 http://www.zope.org/Collectors/Zope/2118


Ah thanks, I missed it.

My variation also creates an expression which would raise a  
KeyError if

evaluated, rather than returning None.  I don't think anybody can
actually be depending on what the current code gives back if an empty
expression is called, so yours should be equally fine.


If you say it used to return the expression context, then I'm pretty  
sure nobody used the result. OTOH I'd rather return None just in  
case, it gives reasonable semantics.



WRT dprecation:  I would actually prefer no* to have the warning,
myself;  I don't think that a usage which has been workable for so  
long

is actually in error.


I agree, we should just decree in Zope 2, empty ZPT path expression  
are allowed and evaluate to None.


Florent


We should probably add a test which verifies compilability of empty
expressions, plus whichever behavior we specify.


--
Florent Guillaume, Nuxeo (Paris, France)   Director of RD
+33 1 40 33 71 59   http://nuxeo.com   [EMAIL PROTECTED]


___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


[Zope-dev] Re: [ZODB-Dev] Re: tempstorage to ZEO?

2006-05-31 Thread Tres Seaver
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1

Eric Brun wrote:
 Hi,
 
 I have bad experence with tempstorage on ZEO (FileStorage with no undo).
 With site with 18000 users (300 per minutes) , the site hang because of
 conflict on ZEO.
 I am very interested by a faster tempstorage like SQLDB

I am working on a memcached-based shared session data container, which
should be both faster than ZEO + tempstorage and conflict-free.


Tres.
- --
===
Tres Seaver  +1 202-558-7113  [EMAIL PROTECTED]
Palladion Software   Excellence by Designhttp://palladion.com
-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.1 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://enigmail.mozdev.org

iD8DBQFEfdyg+gerLs4ltQ4RAtXIAKCTtlsM3Vz75eGsBmt2HB/e4hdsOACgxQX+
+md4NlLnybXuZFzzWyyI+3I=
=xLIQ
-END PGP SIGNATURE-

___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] Re: [ZODB-Dev] Re: tempstorage to ZEO?

2006-05-31 Thread Sidnei da Silva
On Wed, May 31, 2006 at 02:12:48PM -0400, Tres Seaver wrote:
| -BEGIN PGP SIGNED MESSAGE-
| Hash: SHA1
| 
| Eric Brun wrote:
|  Hi,
|  
|  I have bad experence with tempstorage on ZEO (FileStorage with no undo).
|  With site with 18000 users (300 per minutes) , the site hang because of
|  conflict on ZEO.
|  I am very interested by a faster tempstorage like SQLDB
| 
| I am working on a memcached-based shared session data container, which
| should be both faster than ZEO + tempstorage and conflict-free.

Having written a MemcacheCacheManager, I'm very interested in helping
with this. How can I help you?

-- 
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] Re: [ZODB-Dev] Re: tempstorage to ZEO?

2006-05-31 Thread Tino Wildenhain
Sidnei da Silva wrote:
 On Wed, May 31, 2006 at 02:12:48PM -0400, Tres Seaver wrote:
 | -BEGIN PGP SIGNED MESSAGE-
 | Hash: SHA1
 | 
 | Eric Brun wrote:
 |  Hi,
 |  
 |  I have bad experence with tempstorage on ZEO (FileStorage with no undo).
 |  With site with 18000 users (300 per minutes) , the site hang because of
 |  conflict on ZEO.
 |  I am very interested by a faster tempstorage like SQLDB
 | 
 | I am working on a memcached-based shared session data container, which
 | should be both faster than ZEO + tempstorage and conflict-free.
 
 Having written a MemcacheCacheManager, I'm very interested in helping
 with this. How can I help you?
 
Not sure if you know it, but I guess Tres is referring to
http://www.danga.com/memcached/

I was also ofthen thinking if something like that would make
a good client cache - w/o blowing up pythons heap so much.

Regards
Tino
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


[Zope-dev] Zope 2.10 deprecation warnings

2006-05-31 Thread Florent Guillaume
Current bare Zope 2.10 sends some deprecation warnings because it  
itself imports things that it deprecates, this will have to be  
hidden. Suggestions welcome:


- App/Product.py imports ZClasses which are deprecated,

- Products/ZCatalog/ZCatalog.py imports TextIndex (for the Splitters)  
but TextIndex is deprecated.


Also I've checked in a fix for the ZPT warnings such as:
 Init Ambiguous name for method of  
Products.PageTemplates.ZopePageTemplate.ZopePageTemplate: 'manage' !=  
'manage_main'


Florent

--
Florent Guillaume, Nuxeo (Paris, France)   Director of RD
+33 1 40 33 71 59   http://nuxeo.com   [EMAIL PROTECTED]


___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Sidnei da Silva
On Wed, May 31, 2006 at 09:59:36AM -0400, Chris McDonough wrote:
| 
| On May 31, 2006, at 9:55 AM, Sidnei da Silva wrote:
| 
| On Wed, May 31, 2006 at 09:49:49AM -0400, Chris McDonough wrote:
| | I've done this (at least with FileStorage) and it's
| | sllo.  Might be OK for low-traffic sites, but better
| | to implement a custom session data container that stores stuff in
| | SQL.  I have the beginnings of one of these if you want to see it.
| 
| Slow for using sessions? Why didn't you use tempstorage then?
| 
| I think I thought it wouldn't have mattered.  The difference between  
| using sessions against a local filestorage and one on a ZEO server  
| was something like 20X.

So, since I couldn't believe the 20X figure, I wrote a very dumb test
[1] that shows [2] tempstorage to be only slightly slower than
filestorage (roughly 10%) and that adding zeo to the mix makes both of
them about 4X slower, which would be pretty acceptable by my
standards.

I'm looking forward for testing tres' memcached stuff tomorrow.

In the meantime, it would be great if someone can run the script on
different boxes and platforms (I've ran it on Windows on a Intel Dual
Core 3.0) to see if there's any difference.

[1] http://awkly.org/files/zeo-bench/bench.py
[2] http://awkly.org/files/zeo-bench/bench_results.txt

-- 
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214
___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope-dev] tempstorage to ZEO?

2006-05-31 Thread Chris McDonough
Sorry, I've not run your tests but I'll note that they don't take  
into account any concurrency or time lost due to conflict error  
retries.  There are many more conflicts when writing to ZEO-backed  
database in general when there is lots of concurrency because write  
transactions usually take longer.  And even if MVCC bails you out, it  
still takes time to do the conflict resolution.


There is a set of tests explicitly created to torture test session  
conflict rates here:


http://cvs.zope.org/Packages/SessionRig/

See also:

http://www.plope.com/Members/dunny/conflicts/view

- C



On May 31, 2006, at 10:58 PM, Sidnei da Silva wrote:


On Wed, May 31, 2006 at 09:59:36AM -0400, Chris McDonough wrote:
|
| On May 31, 2006, at 9:55 AM, Sidnei da Silva wrote:
|
| On Wed, May 31, 2006 at 09:49:49AM -0400, Chris McDonough wrote:
| | I've done this (at least with FileStorage) and it's
| | sllo.  Might be OK for low-traffic sites, but  
better

| | to implement a custom session data container that stores stuff in
| | SQL.  I have the beginnings of one of these if you want to see  
it.

| 
| Slow for using sessions? Why didn't you use tempstorage then?
|
| I think I thought it wouldn't have mattered.  The difference between
| using sessions against a local filestorage and one on a ZEO server
| was something like 20X.

So, since I couldn't believe the 20X figure, I wrote a very dumb test
[1] that shows [2] tempstorage to be only slightly slower than
filestorage (roughly 10%) and that adding zeo to the mix makes both of
them about 4X slower, which would be pretty acceptable by my
standards.

I'm looking forward for testing tres' memcached stuff tomorrow.

In the meantime, it would be great if someone can run the script on
different boxes and platforms (I've ran it on Windows on a Intel Dual
Core 3.0) to see if there's any difference.

[1] http://awkly.org/files/zeo-bench/bench.py
[2] http://awkly.org/files/zeo-bench/bench_results.txt

--
Sidnei da Silva
Enfold Systemshttp://enfoldsystems.com
Fax +1 832 201 8856 Office +1 713 942 2377 Ext 214



___
Zope-Dev maillist  -  Zope-Dev@zope.org
http://mail.zope.org/mailman/listinfo/zope-dev
**  No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope )


Re: [Zope] os module on different os's

2006-05-31 Thread Chris Withers

garry saddington wrote:

I have a Zope application that runs on WinXP and Debian sarge without
problems. I am using os.popen and popen2 to run locally installed
applications and use their output in Zope (particularly aspell and
diction).


I'd suggest moving to the new subprocess module which packages these up 
in a platform independent way...



problem with recent Distros and this module? Python version is 2.3 on
all systems but I tried 2.4 on FC5 and that failed too. 


You need to be using Zope 2.9 and Python 2.4 to have access to the 
subprocess module, but I'd strongly recommend it in your case...


Chris

--
Simplistix - Content Management, Zope  Python Consulting
   - http://www.simplistix.co.uk

___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope-dev )


[Zope] What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Gfeller Martin
Dear all

after the annoucement of Zope 2.8.7 and 2.10.0.B1, I'm a bit confused
about the difference between the 2.8 and 2.9 lines? Is it mainly Python
2.4 support?

Thank you, and best regards,
Martin Gfeller



___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists -
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Andreas Jung



--On 31. Mai 2006 11:21:04 +0200 Gfeller Martin [EMAIL PROTECTED] 
wrote:



Dear all

after the annoucement of Zope 2.8.7 and 2.10.0.B1, I'm a bit confused
about the difference between the 2.8 and 2.9 lines? Is it mainly Python
2.4 support?



doc/CHANGES.txt is your friend.

-aj

--
ZOPYX Ltd.  Co. KG - Charlottenstr. 37/1 - 72070 Tübingen - Germany
Web: www.zopyx.com - Email: [EMAIL PROTECTED] - Phone +49 - 7071 - 793376
E-Publishing, Python, Zope  Plone development, Consulting


pgpnEYNx2QBKV.pgp
Description: PGP signature
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] [ANN] Zope 2.10.0 beta 1 released

2006-05-31 Thread Bakhtiar A Hamid
On 5/30/06, Andreas Jung [EMAIL PROTECTED] wrote:
Hi all,on behalf of Zope developer community I am pleased to announce the releaseof Zope 2.10.0 beta 1.You can download Zope 2.10.0 beta 1http://www.zope.org/Products/Zope/2.10.0b1/

hi

i can't configure zope. the error is as below

./configure --prefix=/tmp/zope --with-python=/usr/local/py242/bin/python

Using Python interpreter at /usr/local/py242/bin/python

Configuring Zope installation

/usr/local/py242/bin/python: can't open file './inst/configure.py': [Errno 2] No such file or directory


are there files missing?

thanks
-- http://myzope.kedai.com.my - my-zope org
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Lennart Regebro

On 5/31/06, Andreas Jung [EMAIL PROTECTED] wrote:

--On 31. Mai 2006 11:21:04 +0200 Gfeller Martin [EMAIL PROTECTED]
wrote:
 after the annoucement of Zope 2.8.7 and 2.10.0.B1, I'm a bit confused
 about the difference between the 2.8 and 2.9 lines? Is it mainly Python
 2.4 support?

doc/CHANGES.txt is your friend.


And also, the announcements:
http://zope.org/Products/Zope/2.9.0/Zope-2_9_0-released

Some new features of Zope 2.9:

   * ZODB 3.6
   * Five 1.3
   * integration for Zope 3 events for object creation and deletion
   * Zope 3 i18n integration for page templates


--
Lennart Regebro, Nuxeo http://www.nuxeo.com/
CPS Content Management http://www.cps-project.org/
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope-dev )


[Zope] Re: [ANN] Zope 2.10.0 beta 1 released

2006-05-31 Thread Tres Seaver
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1

Bakhtiar A Hamid wrote:

 i can't configure zope.  the error is as below
 
 ./configure --prefix=/tmp/zope --with-python=/usr/local/py242/bin/python
 
 Using Python interpreter at /usr/local/py242/bin/python
 
 Configuring Zope installation
 
 /usr/local/py242/bin/python: can't open file './inst/configure.py': [Errno
 2] No such file or directory

I see that too.

 are there files missing?

Yes.  At least the 'inst' subdirectory and the zpkg-generated setup.py
are missing.


Tres.
- --
===
Tres Seaver  +1 202-558-7113  [EMAIL PROTECTED]
Palladion Software   Excellence by Designhttp://palladion.com
-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.1 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://enigmail.mozdev.org

iD8DBQFEfW8o+gerLs4ltQ4RApT2AKCgXmUSUTxQjAfvMEr+/mGzzQD89wCghQ09
GE+mEU0pABs4Ha/NbJv0vHw=
=cWAF
-END PGP SIGNATURE-

___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] Re: [ANN] Zope 2.10.0 beta 1 released (fwd)

2006-05-31 Thread Andreas Jung



 Forwarded Message 
Date: 31. Mai 2006 12:34:01 +0200
From: Andreas Jung [EMAIL PROTECTED]
To: Tres Seaver [EMAIL PROTECTED], zope@zope.org
Subject: Re: [Zope] Re: [ANN] Zope 2.10.0 beta 1 released



--On 31. Mai 2006 06:25:44 -0400 Tres Seaver [EMAIL PROTECTED] wrote:



are there files missing?


Yes.  At least the 'inst' subdirectory and the zpkg-generated setup.py
are missing.



*sigh* I wished zpkg would disappear in hell forever. This framework raises
more problems than it is trying to solve :-/ I'll check by tomorrow for the
reason.

Andreas

-- End Forwarded Message --



---BeginMessage---



--On 31. Mai 2006 06:25:44 -0400 Tres Seaver [EMAIL PROTECTED] wrote:



are there files missing?


Yes.  At least the 'inst' subdirectory and the zpkg-generated setup.py
are missing.



*sigh* I wished zpkg would disappear in hell forever. This framework raises 
more problems than it is trying to solve :-/ I'll check by tomorrow for the 
reason.


Andreas


pgpxG2iaTfLKh.pgp
Description: PGP signature
---End Message---


pgppKTCl8VLQM.pgp
Description: PGP signature
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


[Zope] relevance ranking in ZCTextIndex or equivalent

2006-05-31 Thread Miles Waller

Hi,

I'm planning to implement a text search where

(match against the title)
 ranks more highly than
(match in the description)
 ranks more highly than
(matches against the body text).

Titles and descriptions are short bits of text, so results in these
categories can be ranked just by the frequency that the word appears in
that part of the text.  Matches against the body text should ideally be
ranked more like ZCTextIndex rather than plain frequency.

My ideas are:

- do three separate searches, and then concatenate the result sets
together.
problem: making sure there are no duplicates in the list without parsing
all the results in their entirety.

- hijack the 'scoring' part of the index, so those results with matches
in the title can have their scores artificially heightened to achieve
the ordering i want
problem: it's compleletely opaque without a lot of study whether this
would achieve what i want.  i'd also need to index the items so the
index knew what was in the title, which could be a problem.

- index title, description and text separately, and then use dieter's
AdvancedQuery product to do the query and combine results
problem: is it possible to get at the scores when the documents are
returned from the index to be able to order them?  are the scores
returned separately, or will each query overwrite the last one?

Has anyone ever tried to do this - or got any pointers - at all?

Thanks in advance,

Miles


___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] relevance ranking in ZCTextIndex or equivalent

2006-05-31 Thread Jonathan


- Original Message - 
From: Miles Waller [EMAIL PROTECTED]

To: zope@zope.org
Sent: Wednesday, May 31, 2006 10:59 AM
Subject: [Zope] relevance ranking in ZCTextIndex or equivalent



Hi,

I'm planning to implement a text search where

(match against the title)
 ranks more highly than
(match in the description)
 ranks more highly than
(matches against the body text).

Titles and descriptions are short bits of text, so results in these
categories can be ranked just by the frequency that the word appears in
that part of the text.  Matches against the body text should ideally be
ranked more like ZCTextIndex rather than plain frequency.

My ideas are:

- do three separate searches, and then concatenate the result sets
together.
problem: making sure there are no duplicates in the list without parsing
all the results in their entirety.

- hijack the 'scoring' part of the index, so those results with matches
in the title can have their scores artificially heightened to achieve
the ordering i want
problem: it's compleletely opaque without a lot of study whether this
would achieve what i want.  i'd also need to index the items so the
index knew what was in the title, which could be a problem.

- index title, description and text separately, and then use dieter's
AdvancedQuery product to do the query and combine results
problem: is it possible to get at the scores when the documents are
returned from the index to be able to order them?  are the scores
returned separately, or will each query overwrite the last one?

Has anyone ever tried to do this - or got any pointers - at all?


A definitely non-trivial task, but here are some ideas to get you pointed in 
the right (I hope) direction:


Try googling, or looking in the zope source for:

data_record_normalized_score_
BaseIndex.py
OkapiIndex.py
SetOps.py
okascore.c


Good Luck!

Jonathan 


___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Gabriel Genellina

At Wednesday 31/5/2006 07:22, Lennart Regebro wrote:


 after the annoucement of Zope 2.8.7 and 2.10.0.B1, I'm a bit confused
 about the difference between the 2.8 and 2.9 lines? Is it mainly Python
 2.4 support?

doc/CHANGES.txt is your friend.


And also, the announcements:
http://zope.org/Products/Zope/2.9.0/Zope-2_9_0-released


I'm confused too. I see new releases of 2.8x, 2.9x and 2.10x, and I 
dont understand the differences.




Gabriel Genellina
Softlab SRL 






___ 
1GB gratis, Antivirus y Antispam 
Correo Yahoo!, el mejor correo web del mundo 
http://correo.yahoo.com.ar 


___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Alec Mitchell

On 5/31/06, Gabriel Genellina [EMAIL PROTECTED] wrote:

At Wednesday 31/5/2006 07:22, Lennart Regebro wrote:

  after the annoucement of Zope 2.8.7 and 2.10.0.B1, I'm a bit confused
  about the difference between the 2.8 and 2.9 lines? Is it mainly Python
  2.4 support?

doc/CHANGES.txt is your friend.

And also, the announcements:
http://zope.org/Products/Zope/2.9.0/Zope-2_9_0-released

I'm confused too. I see new releases of 2.8x, 2.9x and 2.10x, and I
dont understand the differences.


For me the big difference between these is the underlying Zope 3/Five
release, as that's where many of the exciting changes tend to be.

2.8: Zope 3.0/Five 1.1
2.9: Zope 3.2/Five1.3
2.10 Zope 3.3/Five 1.5

Additionally, Zope 2.10 has a number of new features aimed at better
integrating Zope 3/Five features into Zope 2.

Alec
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
http://mail.zope.org/mailman/listinfo/zope-announce

http://mail.zope.org/mailman/listinfo/zope-dev )


[Zope] Re: What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Tres Seaver
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1

Gabriel Genellina wrote:
 At Wednesday 31/5/2006 07:22, Lennart Regebro wrote:
 
  after the annoucement of Zope 2.8.7 and 2.10.0.B1, I'm a bit confused
  about the difference between the 2.8 and 2.9 lines? Is it mainly
 Python
  2.4 support?

 doc/CHANGES.txt is your friend.


 And also, the announcements:
 http://zope.org/Products/Zope/2.9.0/Zope-2_9_0-released
 
 
 I'm confused too. I see new releases of 2.8x, 2.9x and 2.10x, and I dont
 understand the differences.

The releases are as follows:

  - 2.8 is the old stable version, first released a year ago;
the only changes being made there now are to fix really ugly
security bugs, or to stay current with changes to underlying
old stable software (Five 1.0.x, ZODB 3.4.x).  This was
also the last Zope version to support / require Python 2.3.

Plone 2.1.x, for instance, requires a Zope 2.8.x version.

  - 2.9 is the stable or current version, first released in
January (about a month late on our new cycle).  It has newer
versions of the underlying software (ZODB 3.6.x, Five 1.3.x,
Zope3 3.2), and a fairly big pile of new features.  It requires
Python 2.4.

2.9 It will be supported as the old stable version after
2.10 releases

  - 2.10 is the development version, not yet released except in
beta.  It should be released by the end of June.  It will
bundle a newer Zope3 version (3.4), and removes a number of
forks between Zope2 and Zope3 versions of the same features.

  - 2.11 (not yet in development) is scheduled for release in
November, along with Zope3 3.5.


Tres.
- --
===
Tres Seaver  +1 202-558-7113  [EMAIL PROTECTED]
Palladion Software   Excellence by Designhttp://palladion.com
-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.1 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://enigmail.mozdev.org

iD8DBQFEfdvJ+gerLs4ltQ4RAgJTAJ0ePLTuhnVoWYobOyDNRjp+vKkeZQCfbfD2
mKR4fy01FzJ2VDYh5o5Ym1o=
=KaqW
-END PGP SIGNATURE-

___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] Re: What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Ron Bickers
On Wed May 31 2006 14:09, Tres Seaver wrote:

   - 2.10 is the development version, not yet released except in
 beta.  It should be released by the end of June.  It will
 bundle a newer Zope3 version (3.4), and removes a number of
 forks between Zope2 and Zope3 versions of the same features.

Zope 3.4 by the end of June?  3.3 hasn't even been released (except as beta).  
Did I miss something?

-- 
Ron
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] Internet Explorer does not follows redirect, while Firefox does

2006-05-31 Thread Kees de Brabander
Either
  dtml-call RESPONSE.setHeader('pragma','no-cache')
or
  dtml-call RESPONSE.setHeader('Expires',(_.DateTime()-1).rfc822())
or both in the head section of your page will do the trick.
cb

- Original Message - 
From: Marco Bizzarri [EMAIL PROTECTED]
To: Zope Users Mailing List zope@zope.org
Sent: Wednesday, May 31, 2006 7:33 AM
Subject: [Zope] Internet Explorer does not follows redirect,while Firefox
does


 Hi all.

 I don't think this is a specific Zope problem. However, I'm
 experiencing it in a Zope context, and this is why I'm here asking.

 In a custom Zope application, we have a problem with Internet Explorer.

 The application follows a page - submit - redirect - page cycle.

 To state more clearly: the page presented to the user can have a link.
 When the user clicks on the link, something is done, and eventually
 the user is redirected to the same page which will display different
 data based on the results of its previous click.

 The problem is that when IE sees that the result page has the same URL
 as the first page  it does not reload the page and instead shows me
 the cached version.

 The problem is not shown with Firefox.

 As far as I can understand, this is an HTTP header issue, but I would
 like to know if anyone already has experienced this problem, and has
 some solution about it.

 Regards
 Marco
 -- 
 Marco Bizzarri
 http://notenotturne.blogspot.com/
 ___
 Zope maillist  -  Zope@zope.org
 http://mail.zope.org/mailman/listinfo/zope
 **   No cross posts or HTML encoding!  **
 (Related lists -
  http://mail.zope.org/mailman/listinfo/zope-announce
  http://mail.zope.org/mailman/listinfo/zope-dev )


___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )


Re: [Zope] Re: What's the difference between 2.8.x and 2.9.x?

2006-05-31 Thread Tres Seaver
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA1

Ron Bickers wrote:
 On Wed May 31 2006 14:09, Tres Seaver wrote:
 
 
  - 2.10 is the development version, not yet released except in
beta.  It should be released by the end of June.  It will
bundle a newer Zope3 version (3.4), and removes a number of
forks between Zope2 and Zope3 versions of the same features.
 
 
 Zope 3.4 by the end of June?  3.3 hasn't even been released (except as beta). 
  
 Did I miss something?

Just a typo;  sorry for that.


Tres.
- --
===
Tres Seaver  +1 202-558-7113  [EMAIL PROTECTED]
Palladion Software   Excellence by Designhttp://palladion.com
-BEGIN PGP SIGNATURE-
Version: GnuPG v1.4.1 (GNU/Linux)
Comment: Using GnuPG with Thunderbird - http://enigmail.mozdev.org

iD8DBQFEfger+gerLs4ltQ4RAqlAAJ4yUnh4C+8iPo+Ihwm+X4qcM+BNBACgrlyB
oJLnU9ZDVU04diSN81XdJyQ=
=CKcy
-END PGP SIGNATURE-
___
Zope maillist  -  Zope@zope.org
http://mail.zope.org/mailman/listinfo/zope
**   No cross posts or HTML encoding!  **
(Related lists - 
 http://mail.zope.org/mailman/listinfo/zope-announce
 http://mail.zope.org/mailman/listinfo/zope-dev )